﻿//  ChangeWatermark.jsx

/*
    
 Водяной знак защиты текста размещается на слое 'Watermark' в текстовом фрейме с меткой 'Watermark'.
 (в русской версии индизайна метка называется 'Ярлык сценария', доступ к ним Окно > Утилиты > Ярлык сценария)
 Этот фрейм помещается на одной из мастер-страниц работы.
 
 Текст водяного знака должен быть выше защищаемого текста, и это задача верстальщика разместить слои в нужной очерёдности.
 Программа меняет содержимое данного текстового фрейма. 
 При запуске в окне ввода отображается имеющийся в фрейме текст.
 Если фрейм с меткой не найден, то в окне ввода выводятся два вопросительных знака.
 Если в фрейме мало места для введённого текста, об этом будет сообщение. 
 И в окне и фрейме останется прежний текст.
 
 Кнопка 'Изменить водяной знак' не закрывает окно программы. 
 Это сделано для того, чтобы можно было оценить вид нового водяного знака. 
 Для завершения работы есть красный крестик в шапке окна программы.
 
 Слой с таким названием и фреймом для помещения водяного знака есть в файле 'WatermarkSample.idml', он в архиве с данным скриптом.
 Фрейм с водяным знаком можно поместить на мастер-страницу другой работы, и при этом сохранить слой с именем 'Watermark'.
 Для этого перед копированием фрейма надо в панели 'Слои' установить флажок 'Вставить скопированные слои'.

*/

// © Михаил Иванюшин, 2024  |  dotextok@gmail.com  |  dotextok.ru

#targetengine "ChangeWatermark"

var theName = "Watermark"; // название слоя и метки фрейма на нём

var programTitul = "Имитация водяного знака";
if (app.documents.length == 0) {
    alert("Нет открытого документа.", programTitul);
    exit();
    }
var doc = app.activeDocument;
var prevWM = "??";
var tfID = -1;
var noLayer = true;
for (var i = 0; i < doc.layers.length; i++) { // i++
    if (doc.layers[i].name != theName) continue;
    noLayer = false;
    break;
    } // i++
if (noLayer == false) { // !noLayer
    var noFrame = true;
    for (var m = 0; m < doc.masterSpreads.length; m++) { // m++
        var tfN = doc.masterSpreads[m].textFrames.length;
        if (noFrame == false) break;
        if (tfN == 0) continue;
        for (var t = 0; t < tfN; t++) { // t++
            if (doc.masterSpreads[m].textFrames[t].label != theName) continue;
            if (doc.masterSpreads[m].textFrames[t].itemLayer.name != theName) continue;        
            tfID = doc.masterSpreads[m].textFrames[t].id;
            prevWM = doc.textFrames.itemByID(tfID).contents;
            noFrame = false;
            break;
            } // t++
        } // m++    
    if (noFrame == false && doc.textFrames.itemByID(tfID).texts[0].parentStory.overflows) {
        alert("В фрейме с меткой '" + theName + "' вытесненный текст.", programTitul);    
        exit();
        }
    } // !noLayer
//////
var win = new Window ("palette", programTitul);
win.alignChildren = ["fill", "fill"];
win.orientation = "column";
win.add("statictext", undefined, "Введите текст водяного знака");
var wmText = win.add ("edittext {justify: 'center'}", undefined);
wmText.characters = 24;
wmText.text = prevWM;
var buttons = win.add("group");
buttons.orientation = "row";
var info = buttons.add("button", [0,0,28,28], "?");
var action = buttons.add("button", [0,0,290,28], "Изменить водяной знак");
///
win.onClose = function() { app.activate(); }
///
action.onClick = function () { // action.onClick 
var noLayer = true;
for (var i = 0; i < doc.layers.length; i++) { // i++
    if (doc.layers[i].name != theName) continue;
    noLayer = false;
    break;
    } // i++
if (noLayer) {
    alert("Слой '" + theName + "' не найден.", programTitul);
    win.close();   
    app.activate();
    exit();    
    }
var noFrame = true;
for (var m = 0; m < doc.masterSpreads.length; m++) { // m++
    var tfN = doc.masterSpreads[m].textFrames.length;
    if (noFrame == false) break;
    if (tfN == 0) continue;
    for (var t = 0; t < tfN; t++) { // t++
        if (doc.masterSpreads[m].textFrames[t].label != theName) continue;
        if (doc.masterSpreads[m].textFrames[t].itemLayer.name != theName) continue;
        tfID = doc.masterSpreads[m].textFrames[t].id;
        noFrame = false;
        break;
        } // t++
    } // m++
if (noFrame) {
    alert("Не найден текстовый фрейм с меткой '" + theName + "' на слое с таким же названием.", programTitul);
    win.close();   
    app.activate();
    exit();
    }
if (doc.textFrames.itemByID(tfID).texts[0].parentStory.overflows) {
    alert("В фрейме с меткой '" + theName + "' вытесненный текст.", programTitul);    
    win.close();   
    app.activate();
    exit();    
    }
prevWM = doc.textFrames.itemByID(tfID).contents;
doc.textFrames.itemByID(tfID).contents = wmText.text;
if (doc.textFrames.itemByID(tfID).texts[0].parentStory.overflows) {
    alert("В фрейме мало места для этого текста.", programTitul);
    doc.textFrames.itemByID(tfID).contents = prevWM;
    wmText.text = prevWM;
    return;    
    }
return;
} // action.onClick 
///
info.onClick = function () {
alert("== ИМИТАЦИЯ ВОДЯНОГО ЗНАКА НА СТРАНИЦЕ PDF-ФАЙЛА ==\n\nВодяной знак защиты текста размещается на слое ‘Watermark’ в текстовом фрейме с меткой ‘Watermark’.\n(в русской версии индизайна метка называется ‘Ярлык сценария’, доступ к ним Окно > Утилиты > Ярлык сценария)\nЭтот фрейм помещается на одной из мастер-страниц работы.\n   \nТекст водяного знака должен быть выше защищаемого текста, и это задача верстальщика разместить слои в нужной очерёдности.\nПрограмма меняет содержимое данного текстового фрейма. \nПри запуске в окне ввода отображается имеющийся в фрейме текст.\nЕсли фрейм с меткой не найден, то в окне ввода выводятся два вопросительных знака.\nЕсли в фрейме мало места для введённого текста, об этом будет сообщение, и в окне и фрейме останется прежний текст.\n \nКнопка ‘Изменить водяной знак’ не закрывает окно программы. \nЭто сделано для того, чтобы можно было оценить вид нового водяного знака. \nДля завершения работы есть красный крестик в шапке окна программы.\n\nВ архиве два idml-файла с сделанным так водяным знаком. \nОдин называется ‘WatermarkAsProtection.idml’(водяной знак как защита)\nВ PDF-файле будет текст водяного знака поверх текста вёрстки.\n\nВторой файл называется ‘WatermarkAsInformationLine.idml’(водяной знак как информационная строка),\nэто пример помещения какой-то важной информации за пределами полосы набора, но в пространстве страницы.\nВ этом примере внизу полосы набора выводится дата.\n\nДля верстальщика удобство этого подхода в том, что нужно делать меньше действий для достижения того же результата.\nРешение о том, что должно быть в строке водяного знака принимаем не мы, а редактор или еще кто-то.\nЭто ценное указание может прийти в последний момент, а вы не будете тратить время на изменение текста на мастер-странице.\nВы правите текст в окне скрипта, он помещается в верстку и будет в PDF-файле.\n\nСлой с таким названием и фреймом для помещения водяного знака есть в обоих idml-файлах архива.\nФрейм с водяным знаком можно поместить на мастер-страницу другой работы, и при этом сохранить слой с именем ‘Watermark’.\nДля этого перед копированием фрейма надо в панели ‘Слои’ установить флажок ‘Вставить скопированные слои’.\n\nP.S.\nДа, это, конечно, имитация реального водяного знака. Это совсем не тот знак, что можно делать в программе Adobe Acrobat, но бывают случаи, когда такого оформления вполне достаточно.\nДостоинство данного решения - наличие в PDF-файле визуального водяного знака, и получение его не требует дополнительного времени на обработку файла в Adobe Acrobat.\nА что касается возможности удаления его, да, если кто умеет это делать, то может его из PDF-файла убрать. \nТак придуманы средства убрать и настоящий водяной знак, и есть умельцы. Это лишь вопрос времени.\n\n\nhttps://dotextok.ru  |  dotextok@gmail.com", programTitul);
}    
///
win.show();
